@@ -1,5 +1,3 @@
-# Copyright (c) 2015-2018. Mount Sinai School of Medicine
-#
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
@@ -12,8 +10,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from __future__ import print_function, division, absolute_import
-
 from .download import fetch_file, fetch_and_transform, fetch_csv_dataframe
 from .database_helpers import (
     db_from_dataframe,
@@ -30,8 +26,7 @@ from .common import (
     build_local_filename
 )
 from .cache import Cache
-
-__version__ = '1.1.5'
+from .version import __version__
 
 __all__ = [
     'fetch_file',
